@@ -1,5 +1,10 @@
 package GFX::Enhancer::Vector;
 
+###
+### Vector made for colour values (as a numeric bitstring)
+### e.g. 0-255
+###
+
 sub new {
   my ($class, $bitstring) = @_;
   
@@ -13,7 +18,15 @@ sub new {
 sub norm {
   my ($self) = @_;
 
-  return pow($bitstring, 2);
+  return pow($self->{bitstring}, 2);
+}
+
+### angle of angular momentum energy between 2 vectors
+
+sub angle_2_vectors {
+  my ($self, $vector) = @_;
+  
+  return atan2($self->angular_momentum_energy(rand) / $self->norm * $vector->norm);
 }
 
 ### cosinus alteration on this vector (e.g. colour bits as in the subclasses)
